<?php
/**
 * Ascen functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Ascen
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function ascen_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Ascen, use a find and replace
		* to change 'ascen' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'ascen', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'ascen_blog', 410,280, true );
	add_image_size( 'ascen_blog2', 210,220, true );
	add_image_size( 'ascen_blog3', 630,270, true );
	add_image_size( 'ascen_blog4', 850,430, true );
	add_image_size( 'ascen_icon', 60,60, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Header', 'ascen' ),
			'menu-2' => esc_html__( 'Footer', 'ascen' ),
		)
	);
	/*
	 * Set woocommerce support  
	 * 
	*/
	add_theme_support( 'woocommerce' );	
	
	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );
	
	// Add support for editor styles.
	add_theme_support( 'editor-styles' );
	
	// Add support for responsive-embeds.
	add_theme_support( "responsive-embeds" );
	
	// Add support for align-wide.
	add_theme_support( "align-wide" );
	
	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'ascen_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
	
	// add_editor_style
	add_editor_style( 'editor-style.css' );	
}
add_action( 'after_setup_theme', 'ascen_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ascen_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ascen_content_width', 640 );
}
add_action( 'after_setup_theme', 'ascen_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ascen_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'ascen' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'ascen' ),
			'before_widget' => '<section id="%1$s" class="widget blog-right-common %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="cmn-title">',
			'after_title'   => '</h4>',
		)
	);	
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'ascen' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Add widgets here.', 'ascen' ),
			'before_widget' => '<div id="%1$s" class="widget col-xl-3 col-lg-3 col-md-6 col-sm-6 wow fadeInUp %2$s"><div class="single-footer-widget">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<div class="widget-head"><h4 class="white">',
			'after_title'   => '</h4></div>',
		)
	);
	
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'ascen' ),
			'id'            => 'sidebar-3',
			'description'   => esc_html__( 'Add widgets here.', 'ascen' ),
			'before_widget' => '<div id="%1$s" class="widget col-xl-3 col-lg-3 col-md-6 col-sm-6 wow fadeInUp %2$s"><div class="single-footer-widget">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<div class="widget-head"><h4 class="white">',
			'after_title'   => '</h4></div>',
		)
	);	
}
add_action( 'widgets_init', 'ascen_widgets_init' );


//Google Fonts

function ascen_google_fonts_url() {
	$fonts_url = '';
	 
	/* Translators: If there are characters in your language that are not
	* supported by Bubblegum Sans, translate this to 'off'. Do not translate
	* into your own language.
	*/
	$bubblegumSans = _x( 'on', 'Bubblegum Sans font: on or off', 'theme-slug' );
	 
	/* Translators: If there are characters in your language that are not
	* supported by Jost, translate this to 'off'. Do not translate
	* into your own language.
	*/
	$jost = _x( 'on', 'Jost font: on or off', 'theme-slug' );	
	
	/* Translators: If there are characters in your language that are not
	* supported by Nunito, translate this to 'off'. Do not translate
	* into your own language.
	*/
	$nunito = _x( 'on', 'Nunito font: on or off', 'theme-slug' );
	 
		if ( 'off' !== $bubblegumSans || 'off' !== $jost || 'off' !== $nunito ) {
		
			$font_families = array();
		 
		if ( 'off' !== $bubblegumSans ) {
			$font_families[] = 'Bubblegum Sans:400,500,600,700,800,900';
		}
		 
		if ( 'off' !== $jost ) {
			$font_families[] = 'Jost:400,500,600,700,800,900';
		}	 
		
		if ( 'off' !== $nunito ) {
			$font_families[] = 'Nunito:400,500,600,700,800,900';
		}
		 
		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		 
		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}
	 
	return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function ascen_scripts() {
	
	// Add CSS Files
	wp_enqueue_style( 'ascen-google-fonts', ascen_google_fonts_url(), array(), null );
	wp_enqueue_style('bootstrap' , get_template_directory_uri(). '/assets/css/bootstrap.min.css');
	wp_enqueue_style('Font Awesome' , get_template_directory_uri(). '/assets/css/all.css');
	wp_enqueue_style('animate' , get_template_directory_uri(). '/assets/css/animate.css');
	wp_enqueue_style('icomoon' , get_template_directory_uri(). '/assets/css/icomoon.css');
	wp_enqueue_style('magnific-popup' , get_template_directory_uri(). '/assets/css/magnific-popup.css');
	wp_enqueue_style('meanmenu' , get_template_directory_uri(). '/assets/css/meanmenu.css');
	wp_enqueue_style('swiper-bundle.min' , get_template_directory_uri(). '/assets/css/swiper-bundle.min.css');
	wp_enqueue_style('nice-select' , get_template_directory_uri(). '/assets/css/nice-select.css');
	wp_enqueue_style('ascen-main-style' , get_template_directory_uri(). '/assets/css/main.css');
	
	wp_enqueue_style( 'ascen-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'ascen-style', 'rtl', 'replace' );

	// Load JS Files
	wp_enqueue_script( 'viewport-jquery', get_template_directory_uri() . '/assets/js/viewport.jquery.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'bootstrap-bundle', get_template_directory_uri() . '/assets/js/bootstrap.bundle.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'nice-select', get_template_directory_uri() . '/assets/js/jquery.nice-select.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/assets/js/jquery.waypoints.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'counterup', get_template_directory_uri() . '/assets/js/jquery.counterup.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'mixitup', get_template_directory_uri() . '/assets/js/mixitup.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'masonry');
	wp_enqueue_script( 'swiper-bundle', get_template_directory_uri() . '/assets/js/swiper-bundle.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'meanmenu', get_template_directory_uri() . '/assets/js/jquery.meanmenu.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'wow', get_template_directory_uri() . '/assets/js/wow.min.js', array('jquery'), '9865', true );
	wp_enqueue_script( 'ascen-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '9865', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'ascen_scripts' );

// Main menu
function ascen_main_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'menu-1',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => ' ',
		'fallback_cb'       => 'ascen_navwalker::fallback',
		
		)
	); 	
} 

// Footer menu
function ascen_footer_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'menu-2',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => 'footer-menu wow fadeInRight ',
		'fallback_cb'       => 'ascen_navwalker::fallback',
		
		)
	); 	
} 

// ascen wp kses
function ascen_wp_kses($val){
	return wp_kses($val, array(
	
	'p' => array(),
	'span' => array('class' => array(),'id' => array()),
	'div' => array(),
	'strong' => array(),
	'em' => array(),
	'u' => array(),	
	'b' => array(),
	'br' => array(),
	'h1' => array(),
	'h2' => array(),
	'h3' => array(),
	'h4' => array(),
	'h5' => array(),
	'h6' => array(),
	'i'=> array('class' => array(),'id' => array()),
	'div'=> array('class' => array(),'id' => array()),
	'ul'=> array('class' => array(),'id' => array()),
	'li'=> array('class' => array(),'id' => array()),
	'a'=> array('href' => array(),'target' => array()),
	'iframe'=> array('src' => array(),'height' => array(),'width' => array()),
	
	), '');
}

// modify search widget
function ascen_my_search_form( $form ) {
	$form = '
		<div class="search-form">
			<form method="get" action="' . esc_url(home_url( '/' )) . '" >
				<input type="text" value="' . esc_attr(get_search_query()) . '" name="s" id="s" class="search-control" placeholder="' . esc_attr__('Search Query' , 'ascen') .'">
				<button type="submit">
					<i class="fa-solid fa-magnifying-glass"></i>
				</button>
			</form>
		</div>
        ';
	return $form;
}
add_filter( 'get_search_form', 'ascen_my_search_form' );


// comment list modify

function ascen_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>

<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

	<div class="comment-box">
		<div class="comment-avatar">
			<?php echo get_avatar( $comment, 95 ); ?>
		</div>
		<div class="comment-info">
			<h5><?php comment_author_link() ?></h5>
			<span><?php echo esc_html(get_comment_date('F j, Y')); ?></span>
			<?php if ($comment->comment_approved == '0') : ?>
			<p><em><?php esc_html_e('Your comment is awaiting moderation.','ascen'); ?></em></p>
			<?php endif; ?>			
			<?php comment_text(); ?>
			<div class="reply-link"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></div>			
		</div>
	</div>
								
</li>


<?php } 

// comment box title change
add_filter( 'comment_form_defaults', 'ascen_remove_comment_form_allowed_tags' );
function ascen_remove_comment_form_allowed_tags( $defaults ) {

	$defaults['comment_notes_after'] = '';
	$defaults['comment_notes_before'] = '';
	return $defaults;

}

function ascen_comment_reform ($arg) {

$arg['title_reply'] = esc_html__('Write your comment','ascen');
$arg['comment_field'] = '<div class="col-lg-12 mb-xl-3"><div class="comment-grp text-aras position-relative"><textarea id="comment" class="comment_field " name="comment" cols="30" rows="5" placeholder="'. esc_attr__("Write Your Comment Here", "ascen").'" aria-required="true"></textarea><span class="enves"><i class="fa-solid fa-envelope"></i></span></div></div>';


return $arg;

}
add_filter('comment_form_defaults','ascen_comment_reform');

// comment form modify

function ascen_modify_comment_form_fields($fields){
	$commenter = wp_get_current_commenter();
	$req	   = get_option( 'require_name_email' );

	$fields['author'] = '<div class="row g-lg-4 g-3"><div class="col-lg-6"><div class="comment-grp"><input type="text" name="author" id="author" value="'. esc_attr( $commenter['comment_author'] ) .'" placeholder="'. esc_attr__("Your Name *", "ascen").'" size="22" tabindex="1"'. ( $req ? 'aria-required="true"' : '' ).' class=""><i class="fa-solid fa-user"></i></div></div>';

	$fields['email'] = '<div class="col-lg-6"><div class="comment-grp"><input type="text" name="email" id="email" value="'. esc_attr( $commenter['comment_author_email'] ) .'" placeholder="'.esc_attr__("Your Email *", "ascen").'" size="22" tabindex="2"'. ( $req ? 'aria-required="true"' : '' ).' class=""><i class="fa-solid fa-at"></i></div></div>';
	
	$fields['url'] = '<div class="col-lg-12"><div class="comment-grp"><input type="text" name="url" id="url" value="'. esc_attr( $commenter['comment_author_url'] ) .'" placeholder="'. esc_attr__("Website", "ascen").'" size="22" tabindex="2"'. ( $req ? 'aria-required="false"' : '' ).' class="" ><i class="fa-solid fa-globe"></i></div></div></div>';

	return $fields;
}
add_filter('comment_form_default_fields','ascen_modify_comment_form_fields');

// Move Comment Field
function ascen_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'ascen_move_comment_field_to_bottom' );



/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Add Files
 */

require get_template_directory() . '/inc/ascen-functions.php';
require get_template_directory() . '/inc/navwalker.php';
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';
require get_template_directory() . '/inc/required-plugin.php';
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328257&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        